@@ -17,7 +17,9 @@ import salt.config
 import salt.utils.dictupdate
 import salt.utils.files
 
+from saltfactories.factories import cli
 from saltfactories.factories.base import SaltDaemonFactory
+from saltfactories.utils import cli_scripts
 from saltfactories.utils import ports
 
 log = logging.getLogger(__name__)
@@ -28,13 +30,20 @@ class SaltProxyMinionFactory(SaltDaemonFactory):
 
     include_proxyid_cli_flag = attr.ib(default=True, repr=False)
 
-    @staticmethod
+    @classmethod
     def default_config(
-        root_dir, proxy_minion_id, config_defaults=None, config_overrides=None, master_port=None,
+        cls, root_dir, proxy_minion_id, config_defaults=None, config_overrides=None, master=None
     ):
         if config_defaults is None:
             config_defaults = {}
 
+        master_id = master_port = None
+        if master is not None:
+            master_id = master.id
+            master_port = master.config["ret_port"]
+            # Match transport if not set
+            config_defaults.setdefault("transport", master.config["transport"])
+
         conf_dir = root_dir / "conf"
         conf_dir.mkdir(parents=True, exist_ok=True)
         conf_file = str(conf_dir / "proxy")
@@ -55,14 +64,13 @@ class SaltProxyMinionFactory(SaltDaemonFactory):
             "log_file": "logs/proxy.log",
             "log_level_logfile": "debug",
             "loop_interval": 0.05,
-            #'multiprocessing': False,
             "log_fmt_console": "%(asctime)s,%(msecs)03.0f [%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
             "log_fmt_logfile": "[%(asctime)s,%(msecs)03.0f][%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
-            "hash_type": "sha256",
-            "transport": "zeromq",
-            "add_proxymodule_to_opts": False,
             "proxy": {"proxytype": "dummy"},
-            "pytest-minion": {"log": {"prefix": "{{cli_name}}({})".format(proxy_minion_id)},},
+            "pytest-minion": {
+                "master-id": master_id,
+                "log": {"prefix": "{}(id={!r})".format(cls.__name__, proxy_minion_id)},
+            },
         }
         # Merge in the initial default options with the internal _config_defaults
         salt.utils.dictupdate.update(config_defaults, _config_defaults, merge_lists=True)
@@ -81,26 +89,15 @@ class SaltProxyMinionFactory(SaltDaemonFactory):
         root_dir=None,
         config_defaults=None,
         config_overrides=None,
-        master_id=None,
+        master=None,
     ):
-        master = master_port = None
-        if master_id is not None:
-            master = factories_manager.cache["masters"].get(master_id)
-            if master:
-                master_port = master.config.get("ret_port")
-        config = cls.default_config(
+        return cls.default_config(
             root_dir,
             daemon_id,
             config_defaults=config_defaults,
             config_overrides=config_overrides,
-            master_port=master_port,
+            master=master,
         )
-        if master is not None:
-            # The in-memory minion config dictionary will hold a copy of the master config
-            # in order to listen to start events so that we can confirm the proxy-minion is up, running
-            # and accepting requests
-            config["pytest-minion"]["master_config"] = master.config
-        return config
 
     @classmethod
     def _get_verify_config_entries(cls, config):
@@ -139,22 +136,32 @@ class SaltProxyMinionFactory(SaltDaemonFactory):
         Return a list of tuples in the form of `(master_id, event_tag)` check against to ensure the daemon is running
         """
         pytest_config = self.config["pytest-{}".format(self.config["__role"])]
-        if "master_config" not in pytest_config:
+        if not pytest_config.get("master-id"):
             log.warning(
-                "Will not be able to check for start events for %s since it's missing 'master_config' key "
-                "in the 'pytest-%s' dictionary",
+                "Will not be able to check for start events for %s since it's missing the 'master-id' key "
+                "in the 'pytest-%s' dictionary, or it's value is None.",
                 self,
                 self.config["__role"],
             )
         else:
-            yield pytest_config["master_config"]["id"], "salt/{__role}/{id}/start".format(
-                **self.config
+            yield pytest_config["master-id"], "salt/{role}/{id}/start".format(
+                role=self.config["__role"], id=self.id
             )
 
-    # The following methods just route the calls to the right method in the factories manager
-    # while making sure the CLI tools are referring to this daemon
-    def get_salt_call_cli(self, **kwargs):
+    def get_salt_call_cli(self, factory_class=cli.call.SaltCallCliFactory, **factory_class_kwargs):
         """
-        Please see the documentation in :py:class:`~saltfactories.factories.manager.FactoriesManager.get_salt_call_cli`
+        Return a `salt-call` CLI process for this minion instance
         """
-        return self.factories_manager.get_salt_call_cli(self.id, **kwargs)
+        script_path = cli_scripts.generate_script(
+            self.factories_manager.scripts_dir,
+            "salt-call",
+            code_dir=self.factories_manager.code_dir,
+            inject_coverage=self.factories_manager.inject_coverage,
+            inject_sitecustomize=self.factories_manager.inject_sitecustomize,
+        )
+        return factory_class(
+            cli_script_name=script_path,
+            config=self.config.copy(),
+            base_script_args=["--proxyid={}".format(self.id)],
+            **factory_class_kwargs
+        )
